'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CACHE = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /**
                                                                                                                                                                                                                                                                   * @copyright   2017, Miles Johnson
                                                                                                                                                                                                                                                                   * @license     https://opensource.org/licenses/MIT
                                                                                                                                                                                                                                                                   * 
                                                                                                                                                                                                                                                                   */

exports.default = packageData;

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _unicodeEmojiData = require('unicode-emoji-data');

var _emoji = require('emojione/emoji.json');

var _emoji2 = _interopRequireDefault(_emoji);

var _createKeywords = require('./createKeywords');

var _createKeywords2 = _interopRequireDefault(_createKeywords);

var _createShortnames = require('./createShortnames');

var _createShortnames2 = _interopRequireDefault(_createShortnames);

var _toCodepoint = require('./toCodepoint');

var _toCodepoint2 = _interopRequireDefault(_toCodepoint);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Pre-poluate unicode emoji data
const EMOJI = (0, _unicodeEmojiData.expandEmojiData)(_unicodeEmojiData.emojiDataStable);
const BETA_EMOJI = (0, _unicodeEmojiData.expandEmojiData)(_unicodeEmojiData.emojiDataBeta);

// Pre-poluate a mapping of hexcodes to EmojiOne
const EMOJI_ONE = {};

Object.keys(_emoji2.default).forEach(key => {
  const emoji = _emoji2.default[key];

  EMOJI_ONE[emoji.unicode.toUpperCase()] = emoji;
});

// Cache the results after packaging
const CACHE = exports.CACHE = {
  stable: [],
  beta: []
};

function packageData(beta = false) {
  const cacheKey = beta ? 'beta' : 'stable';

  if (CACHE[cacheKey].length) {
    return CACHE[cacheKey];
  }

  (beta ? BETA_EMOJI : EMOJI).forEach(emoji => {
    // Includes ZWJ (zero width joiner) and variation selectors
    let hexcodeZWJ = emoji.presentation && emoji.presentation.default ? emoji.presentation.default : emoji.codepoint;

    // Omit emoji without a hexcode
    if (!hexcodeZWJ) {
      return;
    }

    // Replace spaces with dashes to match EmojiOne
    hexcodeZWJ = hexcodeZWJ.trim().replace(/\s/g, '-');

    // Create a literal unicode character using ZWJ based hexcodes
    const unicode = String.fromCodePoint(...(0, _toCodepoint2.default)(hexcodeZWJ));

    // Create a hexcode without ZWJ and variation selectors
    const hexcode = hexcodeZWJ.replace(/(-(200D|FE0F))/g, '');

    // Package our data
    const extraEmoji = {
      hexcode,
      hexcodeZWJ,
      unicode,
      category: 'symbols',
      codepoint: (0, _toCodepoint2.default)(hexcode),
      keywords: (0, _createKeywords2.default)(emoji.name),
      shortnames: (0, _createShortnames2.default)(emoji.name)
    };

    // Inherit values from EmojiOne if they exist
    if (EMOJI_ONE[hexcode]) {
      const emojiOne = EMOJI_ONE[hexcode];

      extraEmoji.category = emojiOne.category;

      // Remove colons for a smaller filesize
      extraEmoji.shortnames = [emojiOne.shortname, ...emojiOne.aliases].map(sn => sn.replace(/:/g, ''));

      if (emojiOne.keywords.length) {
        extraEmoji.keywords = emojiOne.keywords;
      }

      // Delete the reference so we can infer what's not been used
      delete EMOJI_ONE[hexcode];
    }

    // Cache the merged values
    CACHE[cacheKey].push(_extends({}, emoji, extraEmoji));
  });

  // Verify all of EmojiOne has been used
  if (process.env.NODE_ENV === 'development') {
    const remainingEmojiOnes = Object.values(EMOJI_ONE);

    if (remainingEmojiOnes.length) {
      console.log(_chalk2.default.yellow('Not all EmojiOne definitions have been used!'));

      remainingEmojiOnes.forEach(emoji => {
        // $FlowIgnore Object.values() is typed incorrectly
        console.log(_chalk2.default.gray(`  ${emoji.name}`));
      });
    }
  }

  return CACHE[cacheKey];
}